Declarative annotations for fatal or jfyi error variants.
Expand #[derive(Split)] annotations on error type definitions into two
additional error type definitions that can be converted back to the
original, or the original can be split into one of the two generated error
types.
Determination of fatality can also be forwarded to an inner error that
implements the Fatality trait.
Stands on the shoulders of thiserror.
Traits
- Fatality
- Determine the fatality of an error.
- Nested
- Converts a flat, yet
splitableerror into a nestedResult<Result<_,Jfyi>, Fatal>error type. - Split
- Allows to split an error into two types - a fatal and a informational enum error type, that can be further consumed.